Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(20)

Unified Diff: webrtc/pc/peerconnection.h

Issue 2794943002: Delete MediaController class, move Call ownership to PeerConnection. (Closed)
Patch Set: Revert DCHECK addition. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/pc/peerconnection.h
diff --git a/webrtc/pc/peerconnection.h b/webrtc/pc/peerconnection.h
index 02f56f6c68a3e6dfe64cc6cb24986340e7ee3636..23e7e8e58b083b035872dd137efeeb4f2e82bf92 100644
--- a/webrtc/pc/peerconnection.h
+++ b/webrtc/pc/peerconnection.h
@@ -390,6 +390,9 @@ class PeerConnection : public PeerConnectionInterface,
// This function should only be called from the worker thread.
void StopRtcEventLog_w();
+ // Creates the |*call_| object. Must only be called from the worker thread.
+ void CreateCall_w();
+
// Storing the factory as a scoped reference pointer ensures that the memory
// in the PeerConnectionFactoryImpl remains available as long as the
// PeerConnection is running. It is passed to PeerConnection as a raw pointer.
@@ -405,9 +408,8 @@ class PeerConnection : public PeerConnectionInterface,
PeerConnectionInterface::RTCConfiguration configuration_;
std::unique_ptr<cricket::PortAllocator> port_allocator_;
// The EventLog needs to outlive the media controller.
std::unique_ptr<RtcEventLog> event_log_;
- std::unique_ptr<MediaControllerInterface> media_controller_;
// One PeerConnection has only one RTCP CNAME.
// https://tools.ietf.org/html/draft-ietf-rtcweb-rtp-usage-26#section-4.9
@@ -440,6 +442,7 @@ class PeerConnection : public PeerConnectionInterface,
rtc::scoped_refptr<RtpReceiverProxyWithInternal<RtpReceiverInternal>>>
receivers_;
std::unique_ptr<WebRtcSession> session_;
+ std::unique_ptr<Call> call_;
std::unique_ptr<StatsCollector> stats_;
rtc::scoped_refptr<RTCStatsCollector> stats_collector_;
};
@@ -405,9 +408,8 @@ class PeerConnection : public PeerConnectionInterface,
PeerConnectionInterface::RTCConfiguration configuration_;
std::unique_ptr<cricket::PortAllocator> port_allocator_;
- // The EventLog needs to outlive the media controller.
+ // The EventLog needs to outlive |call_|.
std::unique_ptr<RtcEventLog> event_log_;

Powered by Google App Engine
This is Rietveld 408576698